summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCarlos Garnacho <carlosg@gnome.org>2020-07-06 12:44:26 +0200
committerRobert Mader <robert.mader@posteo.de>2020-08-31 08:40:12 +0000
commit8cc95e44f499d01b25f1f041f1358415f7664941 (patch)
tree74811d9174d1794eaffef0153cf9d38f0c1aa4db
parent6f316345beb98f562577e51daccba7b7f4c980ab (diff)
downloadmutter-8cc95e44f499d01b25f1f041f1358415f7664941.tar.gz
wayland: Reword comment
This is no longer directly related to DBus messages, but our own event queue. Change the wording and use CLUTTER_PRIORITY_EVENTS to make it bolder, even though it's the same than G_PRIORITY_DEFAULT. https://gitlab.gnome.org/GNOME/mutter/-/merge_requests/1286
-rw-r--r--src/wayland/meta-wayland-text-input.c13
1 files changed, 5 insertions, 8 deletions
diff --git a/src/wayland/meta-wayland-text-input.c b/src/wayland/meta-wayland-text-input.c
index 0055bf356..b471e8e1a 100644
--- a/src/wayland/meta-wayland-text-input.c
+++ b/src/wayland/meta-wayland-text-input.c
@@ -156,20 +156,17 @@ meta_wayland_text_input_focus_defer_done (ClutterInputFocus *focus)
if (text_input->done_idle_id != 0)
return;
- /* This operates on 3 principles:
- * - GDBus uses G_PRIORITY_DEFAULT to put messages in the thread default main
- * context.
- * - All relevant ClutterInputFocus methods are ultimately backed by
- * DBus methods inside IBus.
+ /* This operates on 2 principles:
+ * - IM operations come as individual ClutterEvents
* - We want to run .done after them all. The slightly lower
* G_PRIORITY_DEFAULT + 1 priority should ensure we at least group
* all messages seen so far.
*
* FIXME: .done may be delayed indefinitely if there's a high enough
* priority idle source in the main loop. It's unlikely that
* recurring idles run at this high priority though.
*/
- text_input->done_idle_id = g_idle_add_full (G_PRIORITY_DEFAULT + 1,
+ text_input->done_idle_id = g_idle_add_full (CLUTTER_PRIORITY_EVENTS + 1,
done_idle_cb, focus, NULL);
}
@@ -156,20 +156,17 @@ meta_wayland_text_input_focus_defer_done (ClutterInputFocus *focus)
* - We want to run .done after them all. The slightly lower
- * G_PRIORITY_DEFAULT + 1 priority should ensure we at least group
- * all messages seen so far.
+ * CLUTTER_PRIORITY_EVENTS + 1 priority should ensure we at least group
+ * all events seen so far.
*
* FIXME: .done may be delayed indefinitely if there's a high enough